@@ -3,7 +3,7 @@ use strict;
 use warnings;
 BEGIN {
   $Alt::Crypt::RSA::BigInt::AUTHORITY = 'cpan:DANAJ';
-  $Alt::Crypt::RSA::BigInt::VERSION = '0.05';
+  $Alt::Crypt::RSA::BigInt::VERSION = '0.06';
 }
 
 =pod
@@ -24,14 +24,14 @@ unresolved until future versions.
 Math::Pari is completely removed.  This includes the two modules:
 
    - Crypt::Primes   =>   Math::Prime::Util
-   - Crypt::Random   =>   Bytes::Random::Secure
+   - Crypt::Random   =>   Math::Prime::Util
 
 All operations are now performed using Math::BigInt, and prefer the
 GMP and Pari backends.
 
 =head1 PERFORMANCE
 
-Performance using GMP is 3-10 times faster than the Crypt::RSA 1.99.
+Performance using GMP is 3-10 times faster than Crypt::RSA 1.99.
 
 Using Math::BigInt::Pari, it is about half the speed at signing, and
 on par when verifying.
